==> koshoten.net-2.1.2.tar.gz: koshoten-net/admin/shop_info.php <==
<?php
/*
  shop_info.php
  2004/12/2
ǽ2005/6/1

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

  require('includes/application_top.php');

  if ($HTTP_GET_VARS['action']) {
    switch ($HTTP_GET_VARS['action']) {
      case 'update':
        // ʸ̤ι
        if (($HTTP_POST_VARS['edit_x']) || ($HTTP_POST_VARS['edit_y'])) {
        	 // ץӥ塼̤ܥ򲡤줿Ȥ
          $siID = $HTTP_POST_VARS['shop_info_id'];
          $shop_info = array();
          $shop_info['shop_info_title'] = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_title']) : $HTTP_POST_VARS['shop_info_title']);
          $shop_info['shop_info_value'] = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_value']) : $HTTP_POST_VARS['shop_info_value']);
          $shop_info['shop_info_value2'] = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_value2']) : $HTTP_POST_VARS['shop_info_value2']);
          $shop_info['shop_info_note'] = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_note']) : $HTTP_POST_VARS['shop_info_note']);
          $shop_info['allow_edit_title'] = $HTTP_POST_VARS['allow_edit_title'];
          $shop_info['allow_edit_value2'] = $HTTP_POST_VARS['allow_edit_value2'];
          $shop_info['allow_tags'] = $HTTP_POST_VARS['allow_tags'];
          $shop_info['last_modified'] = $HTTP_POST_VARS['last_modified'];
          $siInfo = new objectInfo($shop_info);
          $HTTP_GET_VARS['action'] = 'edit_value';
        } else {
          $shop_info_id = $HTTP_POST_VARS['shop_info_id'];
          $shop_info_title = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_title']) : $HTTP_POST_VARS['shop_info_title']);
          $shop_info_value = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_value']) : $HTTP_POST_VARS['shop_info_value']);
          $shop_info_value2 = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_value2']) : $HTTP_POST_VARS['shop_info_value2']);
          $allow_tags = $HTTP_POST_VARS['allow_tags'];
          $sql_data_array = array('shop_info_title' => $shop_info_title,
                                      'shop_info_value' => $shop_info_value,
                                      'shop_info_value2' => $shop_info_value2,
                                      'allow_tags' => $allow_tags,
                                      'last_modified' =>  'now()');
          tep_db_perform(TABLE_SHOP_INFO, $sql_data_array, 'update', 'shop_info_id = \'' . tep_db_input($shop_info_id) . '\'');
          tep_redirect(tep_href_link(FILENAME_SHOP_INFO));
        }
        break;
      case 'edit_value':
        // ʸ̤Խ
        $siID = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_GET_VARS['siID']) : $HTTP_GET_VARS['siID']);
        $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, shop_info_value2, shop_info_note, allow_edit_title, allow_edit_value2, allow_tags, last_modified from " . TABLE_SHOP_INFO . " where shop_info_id = '" . tep_db_input($siID) . "'");
        $shop_info = tep_db_fetch_array($shop_info_query);
        $siInfo = new objectInfo($shop_info);
        break;
      case 'confirm':
        // ԽƤγǧ
        $siID = $HTTP_POST_VARS['siID'];
        $shop_info_title = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_title']) : $HTTP_POST_VARS['shop_info_title']);
        $shop_info_note = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_note']) : $HTTP_POST_VARS['shop_info_note']);
        $allow_edit_title = $HTTP_POST_VARS['allow_edit_title'];
        $allow_edit_value2 = $HTTP_POST_VARS['allow_edit_value2'];
        $allow_tags = $HTTP_POST_VARS['allow_tags'];
        $shop_info_value = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_value']) : $HTTP_POST_VARS['shop_info_value']);
        $shop_info_value2 = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_POST_VARS['shop_info_value2']) : $HTTP_POST_VARS['shop_info_value2']);
        $shop_info_value = str_replace("\r\n", "\r", $shop_info_value);
        $shop_info_value2 = str_replace("\r\n", "\r", $shop_info_value2);
        $shop_info_value = str_replace("\r", "\n", $shop_info_value);
        $shop_info_value2 = str_replace("\r", "\n", $shop_info_value2);
        $last_modified = $HTTP_POST_VARS['last_modified'];
        break;
    }
  } else {
    // 
    $shop_info_query = tep_db_query("select shop_info_id, shop_info_title, shop_info_note from " . TABLE_SHOP_INFO . " where shop_info_type < 2 order by shop_info_id");
  }
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
<title><?php echo TITLE; ?></title>
<link rel="stylesheet" type="text/css" href="includes/stylesheet.css">
<link rel="stylesheet" type="text/css" href="includes/kn_stylesheet.css">
</head>
<body marginwidth="0" marginheight="0" topmargin="0" bottommargin="0" leftmargin="0" rightmargin="0" bgcolor="#FFFFFF">
<!-- header //-->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->

<!-- body //-->
<table border="0" width="100%" cellspacing="2" cellpadding="2">
  <tr>
    <td width="<?php echo BOX_WIDTH; ?>" valign="top"><table width="<?php echo BOX_WIDTH; ?>" class="knMenuBar">
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
    </table></td>
<!-- body_text //-->
<?php
  if ($HTTP_GET_VARS['action']) {
    switch ($HTTP_GET_VARS['action']) {
      case 'edit_value':
      // Խ
?>
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
          <tr>
            <td class="pageHeading"><?php echo TEXT_EDIT_SHOP_INFO; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><table border="0" width="100%" cellspacing="2" cellpadding="2" class="knBox">
          <tr>
            <td class="knMenu"><?php echo $siInfo->shop_info_note . tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note); ?></td>
          </tr>
          <tr>
            <td class="knMenu" align="right"><?php echo TEXT_LAST_MODIFIED . ' ' . $siInfo->last_modified; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr><?php echo tep_draw_form('shop_info', FILENAME_SHOP_INFO, 'action=confirm') . tep_draw_hidden_field('shop_info_id', $siID); ?>
        <td><table border="0" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main" valign="top">
<?php
         if ($siInfo->allow_edit_title) {
           echo tep_draw_input_field('shop_info_title', $siInfo->shop_info_title, 'size="40"', '', false);
         } else {
           echo $siInfo->shop_info_title . tep_draw_hidden_field('shop_info_title', $siInfo->shop_info_title);
         }
?>
            </td>
          </tr>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main"><?php echo tep_draw_textarea_field('shop_info_value', 'soft', '100%', '20', $siInfo->shop_info_value, '', false); ?></td>
          </tr>
<?php
         if ($siInfo->allow_edit_value2) {
?>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main"><?php echo tep_draw_textarea_field('shop_info_value2', 'soft', '100%', '20', $siInfo->shop_info_value2, '', false); ?></td>
          </tr>
<?php
         } else {
           echo tep_draw_hidden_field('shop_info_value2', $siInfo->shop_info_value2);
         }
?>
          <tr>
            <td class="main" align="right">
<?php
        switch ($siInfo->allow_tags) {
          case '0': $is_valid = false; $is_invalid = true; break;
          case '1':
          default: $is_valid = true; $is_invalid = false;
        }
        echo tep_draw_radio_field('allow_tags', '1', $is_valid) . TEXT_HTML_IS_VALID . '&nbsp;&nbsp;&nbsp;' . tep_draw_radio_field('allow_tags', '0', $is_invalid) . TEXT_HTML_IS_INVALID; 
?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main" align="right"><?php echo tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note) . tep_draw_hidden_field('allow_edit_title', $siInfo->allow_edit_title) . tep_draw_hidden_field('allow_edit_value2', $siInfo->allow_edit_value2) . tep_draw_hidden_field('last_modified', $siInfo->last_modified) . tep_image_submit('button_preview.gif', IMAGE_PREVIEW) . '&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_SHOP_INFO) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>'; ?></td>
          </tr>
        </table></td>
      </form></tr>
<?php
        break;
      case 'confirm':
      // ǧ
?>
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
          <tr>
            <td class="pageHeading"><?php echo TEXT_EDIT_SHOP_INFO_PREVIEW; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><?php echo TEXT_UPDATE_CONFIRM_NOTE; ?></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr><?php echo tep_draw_form('shop_info', FILENAME_SHOP_INFO, 'action=update') . tep_draw_hidden_field('shop_info_id', $siID); ?>
        <td><table border="0" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main"><b><?php echo $shop_info_title . tep_draw_hidden_field('shop_info_title', htmlspecialchars(stripslashes($shop_info_title))); ?></b></td>
          </tr>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main">
<?php
         if ($allow_tags) {
           echo $shop_info_value . tep_draw_hidden_field('shop_info_value', htmlspecialchars(stripslashes($shop_info_value)));
         } else {
           echo nl2br(htmlspecialchars($shop_info_value)) . tep_draw_hidden_field('shop_info_value', htmlspecialchars(stripslashes($shop_info_value)));
         }
?>
            </td>
          </tr>
<?php
         if ($allow_edit_value2) {
?>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main">
<?php
         if ($allow_tags) {
           echo $shop_info_value2 . tep_draw_hidden_field('shop_info_value2', htmlspecialchars(stripslashes($shop_info_value2)));
         } else {
           echo nl2br(htmlspecialchars($shop_info_value2)) . tep_draw_hidden_field('shop_info_value2', htmlspecialchars(stripslashes($shop_info_value2)));
         }
?>
            </td>
          </tr>
<?php
         } else {
           echo tep_draw_hidden_field('shop_info_value2', htmlspecialchars(stripslashes($shop_info_value2)));
         }
?>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main" align="right"><?php echo tep_draw_hidden_field('shop_info_note', $shop_info_note) . tep_draw_hidden_field('allow_edit_title', $allow_edit_title) . tep_draw_hidden_field('allow_edit_value2', $allow_edit_value2) . tep_draw_hidden_field('allow_tags', $allow_tags) . tep_draw_hidden_field('last_modified', $last_modified) . tep_image_submit('button_save.gif', IMAGE_SAVE) . ' ' . tep_image_submit('button_back.gif', IMAGE_BACK, 'name="edit"') . ' <a href="' . tep_href_link(FILENAME_SHOP_INFO) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>'; ?></td>
          </tr>
        </table></td>
      </form></tr>
<?php
    }
  } else {
  // 
?>
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
          <tr>
            <td class="pageHeading"><?php echo HEADING_TITLE; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td align="center"><table border="0" width="100%" cellspacing="0" cellpadding="0" class="knBox">
          <tr>
            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '5'); ?></td>
          </tr>
<?php
    while($shop_info = tep_db_fetch_array($shop_info_query)) {
      $siInfo = new objectInfo($shop_info);
?>
          <tr>
            <td valign="top"><?php echo '<a href="' . tep_href_link(FILENAME_SHOP_INFO, 'action=edit_value&siID=' . $siInfo->shop_info_id) . '" class="knMenu"><b>' . $siInfo->shop_info_title . '</b></a>'; ?></td>
            <td class="knMenu"><?php echo $siInfo->shop_info_note; ?></td>
          </tr>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
<?php
    }
?>
        </table></td>
      </tr>
<?php
  }
?>
    </table></td>
<!-- body_text_eof //-->
  </tr>
</table>
<!-- body_eof //-->

<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
<br>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>

==> koshoten.net-2.2.0.tar.gz: koshoten-net/admin/shop_info.php <==
<?php
/*
  shop_info.php
  2004/12/2
ǽ2005/6/1

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

  require('includes/application_top.php');

  if ($HTTP_GET_VARS['action']) {
    switch ($HTTP_GET_VARS['action']) {
      case 'update':
        // ʸ̤ι
        if (($HTTP_POST_VARS['edit_x']) || ($HTTP_POST_VARS['edit_y'])) {
        	 // ץӥ塼̤ܥ򲡤줿Ȥ
          $siID = $HTTP_POST_VARS['shop_info_id'];
          $shop_info = array();
          $shop_info['shop_info_title'] = $HTTP_POST_VARS['shop_info_title'];
          $shop_info['shop_info_value'] = $HTTP_POST_VARS['shop_info_value'];
          $shop_info['shop_info_value2'] = $HTTP_POST_VARS['shop_info_value2'];
          $shop_info['shop_info_note'] = $HTTP_POST_VARS['shop_info_note'];
          $shop_info['allow_edit_title'] = $HTTP_POST_VARS['allow_edit_title'];
          $shop_info['allow_edit_value2'] = $HTTP_POST_VARS['allow_edit_value2'];
          $shop_info['allow_tags'] = $HTTP_POST_VARS['allow_tags'];
          $shop_info['last_modified'] = $HTTP_POST_VARS['last_modified'];
          $siInfo = new objectInfo($shop_info);
          $HTTP_GET_VARS['action'] = 'edit_value';
        } else {
          $shop_info_id = $HTTP_POST_VARS['shop_info_id'];
          $shop_info_title = tep_db_prepare_input($HTTP_POST_VARS['shop_info_title']);
          $shop_info_value = tep_db_prepare_input($HTTP_POST_VARS['shop_info_value']);
          $shop_info_value2 = tep_db_prepare_input($HTTP_POST_VARS['shop_info_value2']);
          $allow_tags = tep_db_prepare_input($HTTP_POST_VARS['allow_tags']);
          $sql_data_array = array('shop_info_title' => $shop_info_title,
                                      'shop_info_value' => $shop_info_value,
                                      'shop_info_value2' => $shop_info_value2,
                                      'allow_tags' => $allow_tags,
                                      'last_modified' =>  'now()');
          tep_db_perform(TABLE_SHOP_INFO, $sql_data_array, 'update', 'shop_info_id = \'' . tep_db_input($shop_info_id) . '\'');
          tep_redirect(tep_href_link(FILENAME_SHOP_INFO));
        }
        break;
      case 'edit_value':
        // ʸ̤Խ
        $siID = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_GET_VARS['siID']) : $HTTP_GET_VARS['siID']);
        $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, shop_info_value2, shop_info_note, allow_edit_title, allow_edit_value2, allow_tags, last_modified from " . TABLE_SHOP_INFO . " where shop_info_id = '" . tep_db_input($siID) . "'");
        $shop_info = tep_db_fetch_array($shop_info_query);
        $siInfo = new objectInfo($shop_info);
        break;
      case 'confirm':
        // ԽƤγǧ
        $siID = $HTTP_POST_VARS['siID'];
        $shop_info = array();
        $shop_info['shop_info_title'] = $HTTP_POST_VARS['shop_info_title'];
        $shop_info['shop_info_value'] = $HTTP_POST_VARS['shop_info_value'];
        $shop_info['shop_info_value2'] = $HTTP_POST_VARS['shop_info_value2'];
        $shop_info['shop_info_value'] = str_replace("\r\n", "\r", $shop_info['shop_info_value']);
        $shop_info['shop_info_value'] = str_replace("\r", "\n", $shop_info['shop_info_value']);
        $shop_info['shop_info_value2'] = str_replace("\r\n", "\r", $shop_info['shop_info_value2']);
        $shop_info['shop_info_value2'] = str_replace("\r", "\n", $shop_info['shop_info_value2']);
        $shop_info['shop_info_note'] = $HTTP_POST_VARS['shop_info_note'];
        $shop_info['allow_edit_title'] = $HTTP_POST_VARS['allow_edit_title'];
        $shop_info['allow_edit_value2'] = $HTTP_POST_VARS['allow_edit_value2'];
        $shop_info['allow_tags'] = $HTTP_POST_VARS['allow_tags'];
        $shop_info['last_modified'] = $HTTP_POST_VARS['last_modified'];
        $siInfo = new objectInfo($shop_info);
        break;
    }
  } else {
    // 
    $shop_info_query = tep_db_query("select shop_info_id, shop_info_title, shop_info_note from " . TABLE_SHOP_INFO . " where shop_info_type < 2 order by shop_info_id");
  }
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
<title><?php echo TITLE; ?></title>
<link rel="stylesheet" type="text/css" href="includes/stylesheet.css">
<link rel="stylesheet" type="text/css" href="includes/kn_stylesheet.css">
</head>
<body marginwidth="0" marginheight="0" topmargin="0" bottommargin="0" leftmargin="0" rightmargin="0" bgcolor="#FFFFFF">
<!-- header //-->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->

<!-- body //-->
<table border="0" width="100%" cellspacing="2" cellpadding="2">
  <tr>
    <td width="<?php echo BOX_WIDTH; ?>" valign="top"><table width="<?php echo BOX_WIDTH; ?>" class="knMenuBar">
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
    </table></td>
<!-- body_text //-->
<?php
  if ($HTTP_GET_VARS['action']) {
    switch ($HTTP_GET_VARS['action']) {
      case 'edit_value':
      // Խ
?>
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
          <tr>
            <td class="pageHeading"><?php echo TEXT_EDIT_SHOP_INFO; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><table border="0" width="100%" cellspacing="2" cellpadding="2" class="knBox">
          <tr>
            <td class="knMenu"><?php echo $siInfo->shop_info_note . tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note); ?></td>
          </tr>
          <tr>
            <td class="knMenu" align="right"><?php echo TEXT_LAST_MODIFIED . ' ' . $siInfo->last_modified; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr><?php echo tep_draw_form('shop_info', FILENAME_SHOP_INFO, 'action=confirm') . tep_draw_hidden_field('shop_info_id', $siID); ?>
        <td><table border="0" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main" valign="top">
<?php
         if ($siInfo->allow_edit_title) {
           echo tep_draw_input_field('shop_info_title', $siInfo->shop_info_title, 'size="40"', '', false);
         } else {
           echo $siInfo->shop_info_title . tep_draw_hidden_field('shop_info_title', $siInfo->shop_info_title);
         }
?>
            </td>
          </tr>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main"><?php echo tep_draw_textarea_field('shop_info_value', 'soft', '100%', '20', $siInfo->shop_info_value, '', false); ?></td>
          </tr>
<?php
         if ($siInfo->allow_edit_value2) {
?>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main"><?php echo tep_draw_textarea_field('shop_info_value2', 'soft', '100%', '20', $siInfo->shop_info_value2, '', false); ?></td>
          </tr>
<?php
         } else {
           echo tep_draw_hidden_field('shop_info_value2', $siInfo->shop_info_value2);
         }
?>
          <tr>
            <td class="main" align="right">
<?php
        switch ($siInfo->allow_tags) {
          case '0': $is_valid = false; $is_invalid = true; break;
          case '1':
          default: $is_valid = true; $is_invalid = false;
        }
        echo tep_draw_radio_field('allow_tags', '1', $is_valid) . TEXT_HTML_IS_VALID . '&nbsp;&nbsp;&nbsp;' . tep_draw_radio_field('allow_tags', '0', $is_invalid) . TEXT_HTML_IS_INVALID; 
?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main" align="right"><?php echo tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note) . tep_draw_hidden_field('allow_edit_title', $siInfo->allow_edit_title) . tep_draw_hidden_field('allow_edit_value2', $siInfo->allow_edit_value2) . tep_draw_hidden_field('last_modified', $siInfo->last_modified) . tep_image_submit('button_preview.gif', IMAGE_PREVIEW) . '&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_SHOP_INFO) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>'; ?></td>
          </tr>
        </table></td>
      </form></tr>
<?php
        break;
      case 'confirm':
      // ǧ
?>
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
          <tr>
            <td class="pageHeading"><?php echo TEXT_EDIT_SHOP_INFO_PREVIEW; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><?php echo TEXT_UPDATE_CONFIRM_NOTE; ?></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr><?php echo tep_draw_form('shop_info', FILENAME_SHOP_INFO, 'action=update') . tep_draw_hidden_field('shop_info_id', $siID); ?>
        <td><table border="0" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main"><b>
<?php
         if ($siInfo->allow_tags) {
           echo  $siInfo->shop_info_title . tep_draw_hidden_field('shop_info_title', htmlspecialchars($siInfo->shop_info_title));
         } else {
           echo nl2br(htmlspecialchars($siInfo->shop_info_title)) . tep_draw_hidden_field('shop_info_title', htmlspecialchars($siInfo->shop_info_title));
         }
?></b></td>
          </tr>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main">
<?php
         if ($siInfo->allow_tags) {
           echo  $siInfo->shop_info_value . tep_draw_hidden_field('shop_info_value', htmlspecialchars($siInfo->shop_info_value));
         } else {
           echo nl2br(htmlspecialchars($siInfo->shop_info_value)) . tep_draw_hidden_field('shop_info_value', htmlspecialchars($siInfo->shop_info_value));
         }
?>
            </td>
          </tr>
<?php
         if ($siInfo->allow_edit_value2) {
?>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
          <tr>
            <td class="main">
<?php
         if ($siInfo->allow_tags) {
           echo $siInfo->shop_info_value2 . tep_draw_hidden_field('shop_info_value2', htmlspecialchars($siInfo->shop_info_value2));
         } else {
           echo nl2br(htmlspecialchars($siInfo->shop_info_value2)) . tep_draw_hidden_field('shop_info_value2', htmlspecialchars($siInfo->shop_info_value2));
         }
?>
            </td>
          </tr>
<?php
         } else {
           echo tep_draw_hidden_field('shop_info_value2', htmlspecialchars($siInfo->shop_info_value2));
         }
?>
        </table></td>
      </tr>
      <tr>
        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
      </tr>
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="2">
          <tr>
            <td class="main" align="right"><?php echo tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note) . tep_draw_hidden_field('allow_edit_title', $siInfo->allow_edit_title) . tep_draw_hidden_field('allow_edit_value2', $siInfo->allow_edit_value2) . tep_draw_hidden_field('allow_tags', $siInfo->allow_tags) . tep_draw_hidden_field('last_modified', $siInfo->last_modified) . tep_image_submit('button_save.gif', IMAGE_SAVE) . ' ' . tep_image_submit('button_back.gif', IMAGE_BACK, 'name="edit"') . ' <a href="' . tep_href_link(FILENAME_SHOP_INFO) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>'; ?></td>
          </tr>
        </table></td>
      </form></tr>
<?php
    }
  } else {
  // 
?>
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
      <tr>
        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
          <tr>
            <td class="pageHeading"><?php echo HEADING_TITLE; ?></td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td align="center"><table border="0" width="100%" cellspacing="0" cellpadding="0" class="knBox">
          <tr>
            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '5'); ?></td>
          </tr>
<?php
    while($shop_info = tep_db_fetch_array($shop_info_query)) {
      $siInfo = new objectInfo($shop_info);
?>
          <tr>
            <td valign="top"><?php echo '<a href="' . tep_href_link(FILENAME_SHOP_INFO, 'action=edit_value&siID=' . $siInfo->shop_info_id) . '" class="knMenu"><b>' . $siInfo->shop_info_title . '</b></a>'; ?></td>
            <td class="knMenu"><?php echo $siInfo->shop_info_note; ?></td>
          </tr>
          <tr>
            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
          </tr>
<?php
    }
?>
        </table></td>
      </tr>
<?php
  }
?>
    </table></td>
<!-- body_text_eof //-->
  </tr>
</table>
<!-- body_eof //-->

<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
<br>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
